@@ -2,7 +2,7 @@
 *                            recordMyDesktop                                  *
 *******************************************************************************
 *                                                                             *
-*            Copyright (C) 2006,2007 John Varouhakis                          *
+*            Copyright (C) 2006,2007,2008 John Varouhakis                     *
 *                                                                             *
 *                                                                             *
 *   This program is free software; you can redistribute it and/or modify      *
@@ -50,7 +50,7 @@ u_int32_t   *yblocks,
 /**Globals*/
 //I've read somewhere that I'll go to hell for using globals...
 
-int Paused,*Running,Aborted;
+int Paused,*Running,Aborted,PauseStateChanged;
 pthread_cond_t  *time_cond,*pause_cond;
 pthread_mutex_t pause_mutex,time_mutex;
 unsigned char   Yr[256],Yg[256],Yb[256],
