@@ -2,7 +2,7 @@
 *                            recordMyDesktop                                  *
 *******************************************************************************
 *                                                                             *
-*            Copyright (C) 2006,2007 John Varouhakis                          *
+*            Copyright (C) 2006,2007,2008 John Varouhakis                     *
 *                                                                             *
 *                                                                             *
 *   This program is free software; you can redistribute it and/or modify      *
@@ -36,11 +36,30 @@
 /**Function prototypes*/
 
 /**
-* Loop calling XNextEvent.Retrieve and place on
-* list damage events that arive, create damage for new windows.
+* Start listening to damage and substructure notify events
+* (needed before EventLoop call)
 * \param pdata ProgData struct containing all program data
 */
-void *PollDamage(ProgData *pdata);
+void InitEventsPolling(ProgData *pdata);
+
+
+/**
+* Loop calling XNextEvent.Retrieve and place on
+* list damage events that arive, create damage for new windows
+* and pickup key events for shortcuts.
+* \param pdata ProgData struct containing all program data
+*/
+void EventLoop(ProgData *pdata);
+
+/**
+* Loop ,signal timer cond var,sleep-\ 
+*  ^                                 |
+*  |________________________________/
+*   
+*
+* \param pdata ProgData struct containing all program data
+*/
+void *rmdTimer(ProgData *pdata);
 
 /**
 * Retrieve frame form xserver, and transform to a yuv buffer,
@@ -112,13 +131,6 @@ int CollideRects(WGeometry *wgeom1,
                  WGeometry **wgeom_return,
                  int *ngeoms);
 
-/**
-* Broadcast time condition variable, increment frame count.
-*
-* \param signum Number of signal received(unused, always SIGALRM)
-*
-*/
-void SetExpired(int signum);
 
 /**
 * Set up all callbacks and signal handlers
@@ -444,10 +456,6 @@ void *LoadCache(ProgData *pdata);
 */
 void SyncEncodeImageBuffer(ProgData *pdata);
 
-/**
-* Stop the timer
-*/
-void CancelTimer(void);
 
 /**
 * As EncodeSoundBuffer, only with the assumption that
@@ -676,5 +684,163 @@ void BlocksFromList(RectArea **root,
                     unsigned int blocknum_x,
                     unsigned int blocknum_y);
 
+
+/**
+*   Currently only frees some memory
+*   (y,u,v blocks)
+*
+*
+*/
+void CleanUp(void);
+
+
+/*
+ * Check a shortcut combination and if valid, 
+ * register it, on the root window.
+ *
+ * \param dpy Connection to the X Server
+ *
+ * \param root Root window id
+ *
+ * \param shortcut String represantation of the shortcut
+ *
+ * \param HotKey Pre-allocated struct that is filled with the 
+ *               modifiers and the keycode, for checks on incoming 
+ *               keypress events. Left untouched if the call fails.
+ *
+ *  
+ *  \returns 0 on Success, 1 on Failure. 
+ *
+ */
+int RegisterShortcut(Display *dpy,
+                     Window root,
+                     const char *shortcut,
+                     HotKey *hotkey);
+
+/*
+ * Handling of X errors.
+ * Ignores, bad access when registering shortcuts
+ * and BadWindow on XQueryTree
+ *
+ * \param dpy Connection to the X Server
+ *
+ * \param e XErrorEvent struct containing error info
+ *
+ * \returns 0 on the two ignored cases, calls exit(1)
+ *            otherwise.
+ *
+ */
+int rmdErrorHandler(Display *dpy,XErrorEvent *e);
+
+/*
+ * Create a frame that marks the recording area.
+ *
+ * \param dpy Connection to the X Server
+ *
+ * \param screen Recorded screen
+ *
+ * \param root Root window of the display
+ *
+ * \param x X pos of the recorded area
+ *
+ * \param y Y pos of the recorded area
+ *
+ * \param width Width of the recorded area
+ *
+ * \param height Height of the recorded area
+ *
+ * \returns The WindowID of the frame
+ *
+ */
+Window rmdFrameInit(Display *dpy,
+                    int screen,
+                    Window root,
+                    int x,
+                    int y,
+                    int width,
+                    int height);
+
+
+/*
+ * Move the frame (subtracts the borderwidth)
+ *
+ * \param dpy Connection to the X Server
+ *
+ * \param win WindowId of the frame
+ *
+ * \param x New X pos of the recorded area
+ *
+ * \param y New Y pos of the recorded area
+ *
+ */
+void rmdMoveFrame(Display *dpy,
+                  Window win,
+                  int x,
+                  int y);
+
+
+/*
+ * Redraw the frame that marks the recording area.
+ *
+ * \param dpy Connection to the X Server
+ *
+ * \param screen Recorded screen
+ *
+ * \param win WindoID of the frame
+ *
+ * \param width Width of the recorded area
+ *
+ * \param height Height of the recorded area
+ *
+ */
+void rmdDrawFrame(Display *dpy,
+                  int screen,
+                  Window win,
+                  int width,
+                  int height);
+
+
+/*
+ * Create a text file that holds the required
+ * capture attributes, in the cache directory.
+ *
+ * \param pdata ProgData struct containing all program data
+ *
+ * \returns 0 on Success, 1 on failure
+ *
+ */ 
+int WriteSpecsFile(ProgData *pdata);
+
+
+
+/*
+ * Read the  text file that holds the required
+ * capture attributes, in the cache directory.
+ *
+ * \param pdata ProgData struct that will be fille 
+ *        with  all program data
+ *
+ * \returns 0 on Success, 1 on failure
+ *
+ */ 
+int ReadSpecsFile(ProgData *pdata);
+
+
+/*
+ * Rescue a previous recording, found in 
+ * the given path.
+ *
+ * \param path Path to the cache folder.
+ *
+ * \returns 0 on Success, 1 on failure
+ *
+ */
+int rmdRescue(const char *path);
+
 #endif
 
+
+
+
+
+
