@@ -2,7 +2,7 @@
 *                            recordMyDesktop                                  *
 *******************************************************************************
 *                                                                             *
-*            Copyright (C) 2006,2007 John Varouhakis                          *
+*            Copyright (C) 2006,2007,2008 John Varouhakis                     *
 *                                                                             *
 *                                                                             *
 *   This program is free software; you can redistribute it and/or modify      *
@@ -207,13 +207,14 @@
     (args)->use_jack=\
     (args)->noshared=\
     (args)->no_encode=\
+    (args)->noframe=\
     (args)->jack_nports=0;\
     (args)->jack_ringbuffer_secs=3.0;\
     (args)->jack_port_names=NULL;\
     (args)->zerocompression=\
     (args)->no_quick_subsample=1;\
     (args)->filename=(char *)malloc(8);\
-    strcpy((args)->filename,"out.ogg");\
+    strcpy((args)->filename,"out.ogv");\
     (args)->cursor_color=1;\
     (args)->have_dummy_cursor=0;\
     (args)->xfixes_cursor=1;\
@@ -228,6 +229,10 @@
     (args)->s_quality=10;\
     (args)->workdir=(char *)malloc(5);\
     strcpy((args)->workdir,"/tmp");\
+    (args)->pause_shortcut=(char *)malloc(15);\
+    strcpy((args)->pause_shortcut,"Control+Mod1+p");\
+    (args)->stop_shortcut=(char *)malloc(15);\
+    strcpy((args)->stop_shortcut,"Control+Mod1+s");\
 }
 
 #define QUERY_DISPLAY_SPECS(display,specstruct){\
