@@ -2,7 +2,7 @@
 *                            recordMyDesktop                                  *
 *******************************************************************************
 *                                                                             *
-*            Copyright (C) 2006,2007 John Varouhakis                          *
+*            Copyright (C) 2006,2007,2008 John Varouhakis                     *
 *                                                                             *
 *                                                                             *
 *   This program is free software; you can redistribute it and/or modify      *
@@ -19,8 +19,6 @@
 *   along with this program; if not, write to the Free Software               *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA  *
 *                                                                             *
-*                                                                             *
-*                                                                             *
 *   For further information contact me at johnvarouhakis@gmail.com            *
 ******************************************************************************/
 
@@ -165,10 +163,13 @@ typedef struct _ProgArgs{
     int v_bitrate,v_quality,s_quality;  //video bitrate,video-sound quality
     int encOnTheFly;    //encode while recording, no caching(default 0)
     char *workdir;      //directory to be used for cache files(default $HOME)
-    int zerocompression;//image data are always flushed uncompressed
-    int overwrite;      //overwite a previously existing file
-                        //(do not add a .number postfix)
-    int use_jack;       //record audio with jack
+    char *pause_shortcut;   //pause/unpause shortcut sequence(Control+Alt+p)
+    char *stop_shortcut;    //stop shortcut sequence(Control+Alt+s)
+    int noframe;            //don't draw a frame around the recording area
+    int zerocompression;    //image data are always flushed uncompressed
+    int overwrite;          //overwite a previously existing file
+                            //(do not add a .number postfix)
+    int use_jack;           //record audio with jack
     unsigned int jack_nports;
     char **jack_port_names;
     float jack_ringbuffer_secs;
@@ -217,6 +218,7 @@ typedef struct _CacheData{
                         //and also, a frontend can identify
                         //leftovers from a possible crash
                         //and delete them
+            *specsfile, //workdir+projname+specs.txt
             *imgdata,   //workdir+projname+img.out.gz
             *audiodata; //workdir+projname+audio.pcm
 
@@ -253,6 +255,12 @@ typedef struct _JackData{
 }JackData;
 #endif
 
+typedef struct _HotKey{     //Hold info about the shortcuts
+    int modnum;             //modnum is the number of modifier masks
+    unsigned int mask[4];  //that should be checked (the initial
+    int key;                //user requested modifier plus it's
+}HotKey;                    //combinations with LockMask and NumLockMask).
+
 //this structure holds any data related to the program
 //It's usage is mostly to be given as an argument to the
 //threads,so they will have access to the program data, avoiding
@@ -262,20 +270,20 @@ typedef struct _ProgData{
     ProgArgs args;          //the program arguments
     DisplaySpecs specs;     //Display specific information
     BRWindow brwin;         //recording window
-    RectArea *rect_root[2]; //the interchanging list roots for storing
+    RectArea *rect_root;    //the interchanging list roots for storing
                             //the changed regions
     SndBuffer   *sound_buffer;
     EncData     *enc_data;
     CacheData   *cache_data;
+    HotKey      pause_key,  //Shortcuts
+                stop_key;
 #ifdef HAVE_JACK_H
     JackData    *jdata;
 #endif
 /**X related info*/
     Display *dpy;           //curtrent display
 /** Mutexes*/
-    pthread_mutex_t list_mutex[2],  //mutexes for concurrency
-                                    //protection of the lists
-                    sound_buffer_mutex,
+    pthread_mutex_t sound_buffer_mutex,
                     snd_buff_ready_mutex,
                     img_buff_ready_mutex,
                     theora_lib_mutex,
@@ -311,8 +319,8 @@ typedef struct _ProgData{
     unsigned int periodtime,//time that a sound buffer lasts (microsecs)
                 frametime;  //time that a frame lasts (microsecs)
     char    *window_manager;   //name of the window manager at program launch
-    int list_selector,      //selector for the rect_roots
-        damage_event,       //damage event base code
+    Window  shaped_w;       //frame
+    int damage_event,       //damage event base code
         damage_error,       //damage error base code
         shm_opcode,         //MIT-Shm opcode
         running,            //1 while the program is capturing/paused/encoding
@@ -321,9 +329,11 @@ typedef struct _ProgData{
         v_encoding_clean,       //  >>  >>
         v_enc_thread_waiting,   //these indicate a wait
         th_enc_thread_waiting,  //condition on the cond vars.
+        timer_alive,        //determines loop of timer thread
         hard_pause,         //if sound device doesn't support pause
                             //we have to close and reopen
-        avd;                //syncronization among audio and video
+        avd,                //syncronization among audio and video
+        sound_framesize;    //size of each sound frame
 #ifdef HAVE_LIBASOUND
     snd_pcm_t *sound_handle;
     snd_pcm_uframes_t periodsize;
