@@ -2,7 +2,7 @@
 *                            recordMyDesktop                                  *
 *******************************************************************************
 *                                                                             *
-*            Copyright (C) 2006,2007 John Varouhakis                          *
+*            Copyright (C) 2006,2007,2008 John Varouhakis                     *
 *                                                                             *
 *                                                                             *
 *   This program is free software; you can redistribute it and/or modify      *
@@ -27,16 +27,16 @@
 
 #include <recordmydesktop.h>
 
-#ifdef USE_GLX_CAP
-    #include <GL/gl.h>
-    #include <GL/glu.h>
-    #include <GL/glx.h>
-#endif
 
+//besides taking the first screenshot, this functions primary purpose is to 
+//initialize the structures and memory.
 int FirstFrame(ProgData *pdata,XImage **image,XShmSegmentInfo *shminfo,
                char **pxl_data){
 
     if((pdata->args.noshared)){
+
+        *pxl_data=(char *)malloc(pdata->brwin.nbytes);
+        
         (*image)=XCreateImage(pdata->dpy,
                             pdata->specs.visual,
                             pdata->specs.depth,
@@ -54,7 +54,6 @@ int FirstFrame(ProgData *pdata,XImage **image,XShmSegmentInfo *shminfo,
                    pdata->brwin.rgeom.y,
                    pdata->brwin.rgeom.width,
                    pdata->brwin.rgeom.height);
-        *pxl_data=(char *)malloc(pdata->brwin.nbytes);
     }
     else{
         (*image)=XShmCreateImage(pdata->dpy,
@@ -114,6 +113,8 @@ void BRWinCpy(BRWindow *target,BRWindow *source){
 
 }
 
+//recenters the capture area to the mouse
+//without exiting the display bounding box
 void MoveCaptureArea(   BRWindow *brwin,
                         int cursor_x,
                         int cursor_y,
@@ -131,15 +132,17 @@ void MoveCaptureArea(   BRWindow *brwin,
                                height-brwin->rgeom.height:t_y);
 }
 
+
+
 void *GetFrame(ProgData *pdata){
     int i=0,
-        tlist_sel=0,
         blocknum_x=pdata->enc_data->yuv.y_width/Y_UNIT_WIDTH,
         blocknum_y=pdata->enc_data->yuv.y_height/Y_UNIT_WIDTH;
     unsigned int msk_ret;
     WGeometry mouse_pos_abs,mouse_pos_rel,mouse_pos_temp;
     BRWindow temp_brwin;
-    Window root_ret,child_ret;
+    Window root_ret,
+           child_ret; //Frame
     XFixesCursorImage *xcim=NULL;
     XImage *image=NULL,*image_back=NULL;          //the image that holds
                                         //the current full screenshot
@@ -150,20 +153,6 @@ void *GetFrame(ProgData *pdata){
 
 
 
-#ifdef USE_GLX_CAP
-    XVisualInfo vinfo_return;
-    XMatchVisualInfo(pdata->dpy,pdata->specs.screen,pdata->specs.depth,TrueColor,&vinfo_return );
-    GLXContext ctx=glXCreateContext( pdata->dpy,
-                      &vinfo_return,
-                      NULL,
-                      True);
-//     fprintf(stderr,"here %d",pdata->args.windowid);
-    glXMakeCurrent( pdata->dpy,
-                    pdata->brwin.windowid,
-                    ctx);
-
-    glReadBuffer(GL_FRONT);
-#endif
 
     img_sel=d_buff=pdata->args.full_shots;
 
@@ -202,38 +191,55 @@ void *GetFrame(ProgData *pdata){
 
     }
 
+    if(!pdata->args.noframe){
+        pdata->shaped_w=rmdFrameInit(pdata->dpy,
+                              pdata->specs.screen,
+                              pdata->specs.root,
+                              pdata->brwin.rgeom.x,
+                              pdata->brwin.rgeom.y,
+                              pdata->brwin.rgeom.width,
+                              pdata->brwin.rgeom.height);
+        XSelectInput(pdata->dpy,pdata->shaped_w,ExposureMask);
+    }
 
     mouse_pos_abs.x=mouse_pos_temp.x=0;
     mouse_pos_abs.y=mouse_pos_temp.y=0;
     mouse_pos_abs.width=mouse_pos_temp.width=pdata->dummy_p_size;
     mouse_pos_abs.height=mouse_pos_temp.height=pdata->dummy_p_size;
+    
+    //This is the the place where we call XSelectInput
+    //and arrange so that we listen for damage on all 
+    //windows
+    InitEventsPolling(pdata);
 
     while(pdata->running){
 
         //if we are left behind we must not wait.
         //also before actually pausing we must make sure the streams
         //are synced. sound stops so this should only happen quickly.
-        if(pdata->avd>0){
+        if(pdata->avd>0 || pdata->args.nosound){
             pthread_mutex_lock(&time_mutex);
             pthread_cond_wait(&pdata->time_cond,&time_mutex);
             pthread_mutex_unlock(&time_mutex);
             if(Paused){
-                pthread_mutex_lock(&pause_mutex);
-                pthread_cond_wait(&pdata->pause_cond,&pause_mutex);
-                pthread_mutex_unlock(&pause_mutex);
+                //this is necessary since event loop processes
+                //the shortcuts which will unpause the program
+                EventLoop(pdata);
+                continue;
             }
         }
+        //read all events and construct list with damage 
+        //events (if not full_shots)
+        EventLoop(pdata);
+
+        //switch back and front buffers (full_shots only)
         if(d_buff)
             img_sel=(img_sel)?0:1;
         capture_busy=1;
 
         BRWinCpy(&temp_brwin,&pdata->brwin);
-        //mutexes and lists with changes are useless when full_shots is enabled
-        if(!pdata->args.full_shots){
-            tlist_sel=pdata->list_selector;
-            pdata->list_selector=((pdata->list_selector+1)%2);
-            pthread_mutex_lock(&pdata->list_mutex[tlist_sel]);
-        }
+
+
         if(pdata->args.xfixes_cursor ||
            pdata->args.have_dummy_cursor||
            pdata->args.follow_mouse){
@@ -250,7 +256,7 @@ void *GetFrame(ProgData *pdata){
                     (mouse_pos_temp.y>=0)&&
                     (mouse_pos_temp.width>0)&&
                     (mouse_pos_temp.height>0))
-                    RectInsert(&pdata->rect_root[tlist_sel],&mouse_pos_temp);
+                    RectInsert(&pdata->rect_root,&mouse_pos_temp);
             }
             //find new one
             if(pdata->args.xfixes_cursor){
@@ -276,6 +282,13 @@ void *GetFrame(ProgData *pdata){
                             ((pdata->args.xfixes_cursor)?xcim->yhot:0),
                             pdata->specs.width,
                             pdata->specs.height);
+            if(!pdata->args.noframe){
+                rmdMoveFrame(pdata->dpy,
+                             pdata->shaped_w,
+                             temp_brwin.rgeom.x,
+                             temp_brwin.rgeom.y);
+
+            }
         }
 
         if(!pdata->args.full_shots){
@@ -283,7 +296,7 @@ void *GetFrame(ProgData *pdata){
             UpdateImage(pdata->dpy,
                         &pdata->enc_data->yuv,
                         &pdata->specs,
-                        &pdata->rect_root[tlist_sel],
+                        &pdata->rect_root,
                         &temp_brwin,
                         pdata->enc_data,
                         image->data,
@@ -291,7 +304,7 @@ void *GetFrame(ProgData *pdata){
                         &shminfo,
                         pdata->shm_opcode,
                         pdata->args.no_quick_subsample);
-            BlocksFromList(&pdata->rect_root[tlist_sel],
+            BlocksFromList(&pdata->rect_root,
                            temp_brwin.rgeom.x,
                            temp_brwin.rgeom.y,
                            pdata->enc_data->yuv.y_width/Y_UNIT_WIDTH,
@@ -306,20 +319,10 @@ void *GetFrame(ProgData *pdata){
                                         ((unsigned char*)image_back->data));
 
             if(!pdata->args.noshared){
-#ifdef USE_GLX_CAP
-                glReadPixels(0,
-                             0,
-                             temp_brwin.rgeom.width,
-                             temp_brwin.rgeom.height,
-                             GL_RGBA,
-                             GL_UNSIGNED_BYTE,
-                             front_buff);
-#else
                 XShmGetImage(pdata->dpy,pdata->specs.root,
                             ((!img_sel)?image:image_back),
                             (temp_brwin.rgeom.x),
                             (temp_brwin.rgeom.y),AllPlanes);
-#endif
             }
             if(pdata->args.noshared){
                 GetZPixmap( pdata->dpy,
@@ -418,8 +421,7 @@ void *GetFrame(ProgData *pdata){
             }
         }
         if(!pdata->args.full_shots){
-            ClearList(&pdata->rect_root[tlist_sel]);
-            pthread_mutex_unlock(&pdata->list_mutex[tlist_sel]);
+            ClearList(&pdata->rect_root);
         }
         if(encoder_busy){
             frames_lost++;
@@ -429,9 +431,12 @@ void *GetFrame(ProgData *pdata){
         pthread_mutex_unlock(&pdata->img_buff_ready_mutex);
         capture_busy=0;
     }
-#ifdef USE_GLX_CAP
-   glXDestroyContext(pdata->dpy,ctx);
-#endif
+
+    if(!pdata->args.noframe){
+        XDestroyWindow(pdata->dpy,pdata->shaped_w);
+    }
+
+
     pthread_mutex_lock(&pdata->img_buff_ready_mutex);
     pthread_cond_broadcast(&pdata->image_buffer_ready);
     pthread_mutex_unlock(&pdata->img_buff_ready_mutex);
