@@ -2,7 +2,7 @@
 *                            recordMyDesktop                                  *
 *******************************************************************************
 *                                                                             *
-*            Copyright (C) 2006,2007 John Varouhakis                          *
+*            Copyright (C) 2006,2007,2008 John Varouhakis                     *
 *                                                                             *
 *                                                                             *
 *   This program is free software; you can redistribute it and/or modify      *
@@ -62,9 +62,7 @@ int InitializeData(ProgData *pdata,
         pdata->dummy_p_size=0;
 
 
-    pdata->rect_root[0]=pdata->rect_root[1]=NULL;
-    pthread_mutex_init(&pdata->list_mutex[0],NULL);
-    pthread_mutex_init(&pdata->list_mutex[1],NULL);
+    pdata->rect_root=NULL;
     pthread_mutex_init(&pdata->sound_buffer_mutex,NULL);
     pthread_mutex_init(&pdata->snd_buff_ready_mutex,NULL);
     pthread_mutex_init(&pdata->img_buff_ready_mutex,NULL);
@@ -82,12 +80,13 @@ int InitializeData(ProgData *pdata,
     pthread_cond_init(&pdata->theora_lib_clean,NULL);
     pthread_cond_init(&pdata->vorbis_lib_clean,NULL);
     pdata->th_encoding_clean=pdata->v_encoding_clean=1;
-    pdata->list_selector=Paused=Aborted=pdata->avd=0;
+    Paused=Aborted=pdata->avd=0;
     pdata->sound_buffer=NULL;
     pdata->running=1;
     time_cond=&pdata->time_cond;
     pause_cond=&pdata->pause_cond;
     Running=&pdata->running;
+    PauseStateChanged=0;
 
     if(!pdata->args.nosound){
         if(!pdata->args.use_jack){
@@ -100,6 +99,10 @@ int InitializeData(ProgData *pdata,
                                         &pdata->periodsize,
                                         &pdata->periodtime,
                                         &pdata->hard_pause);
+            pdata->sound_framesize=((snd_pcm_format_width(
+                                     SND_PCM_FORMAT_S16_LE))/8)*
+                                     pdata->args.channels;
+
             if(pdata->sound_handle==NULL){
 #else
             pdata->sound_handle=OpenDev(pdata->args.device,
@@ -109,6 +112,7 @@ int InitializeData(ProgData *pdata,
                             ((pdata->args.channels<<1)*pdata->args.frequency);
             //when using OSS periodsize serves as an alias of buffsize
             pdata->periodsize=pdata->args.buffsize;
+            pdata->sound_framesize=pdata->args.channels<<1;
             if(pdata->sound_handle<0){
 #endif
                 fprintf(stderr,"Error while opening/configuring soundcard %s\n"
@@ -137,6 +141,9 @@ int InitializeData(ProgData *pdata,
             pdata->args.channels=pdata->jdata->nports;
             pdata->periodtime=(1000000*pdata->args.buffsize)/
                               pdata->args.frequency;
+            pdata->sound_framesize=sizeof(jack_default_audio_sample_t)*
+                                   pdata->jdata->nports;
+
 #else
             fprintf(stderr,"Should not be here!\n");
             exit(-1);
@@ -157,6 +164,13 @@ int InitializeData(ProgData *pdata,
         pdata->enc_data->yuv.v[i]=pdata->enc_data->yuv.u[i]=127;
     }
 
+    yblocks=malloc(sizeof(u_int32_t)*(pdata->enc_data->yuv.y_width/Y_UNIT_WIDTH)*
+                (pdata->enc_data->yuv.y_height/Y_UNIT_WIDTH));
+    ublocks=malloc(sizeof(u_int32_t)*(pdata->enc_data->yuv.y_width/Y_UNIT_WIDTH)*
+                (pdata->enc_data->yuv.y_height/Y_UNIT_WIDTH));
+    vblocks=malloc(sizeof(u_int32_t)*(pdata->enc_data->yuv.y_width/Y_UNIT_WIDTH)*
+                (pdata->enc_data->yuv.y_height/Y_UNIT_WIDTH));
+
     pdata->frametime=(1000000)/pdata->args.fps;
     return 0;
 
