@@ -2,7 +2,7 @@
 *                            recordMyDesktop                                  *
 *******************************************************************************
 *                                                                             *
-*            Copyright (C) 2006,2007 John Varouhakis                          *
+*            Copyright (C) 2006,2007,2008 John Varouhakis                     *
 *                                                                             *
 *                                                                             *
 *   This program is free software; you can redistribute it and/or modify      *
@@ -101,9 +101,15 @@ int ParseArgs(int argc,char **argv,ProgArgs *arg_return){
     "\t-s_quality n\t\tDesired audio quality(-1 to 10).\n\n"
 
     "Misc Options:\n"
+    "\t-rescue path_to_data\tEncode data from a previous, crashed, session.\n"
     "\t--no-wm-check\t\tDo not try to detect"
     " the window manager(and set options according to it)\n"
 
+    "\t-pause-shortcut MOD+KEY\tShortcut that will be used for (un)pausing" 
+    "(default Control+Mod1+p).\n"
+    "\t-stop-shortcut MOD+KEY\tShortcut that will be used to stop the "
+    "recording (default Control+Mod1+s).\n" 
+
     "\t--compress-cache\tImage data are cached with light compression.\n"
     "\t-workdir DIR\t\tLocation where a temporary directory"
     " will be created to hold project files(default $HOME).\n"
@@ -115,7 +121,7 @@ int ParseArgs(int argc,char **argv,ProgArgs *arg_return){
     " delete it\n"
 
     "\t\t\t\t(default is to add a number postfix to the new one).\n"
-    "\t-o filename\t\tName of recorded video(default out.ogg).\n"
+    "\t-o filename\t\tName of recorded video(default out.ogv).\n"
     "\n\tIf no other options are specified, filename can be given "
     "without the -o switch.\n\n\n";
 
@@ -414,6 +420,30 @@ int ParseArgs(int argc,char **argv,ProgArgs *arg_return){
             }
             i++;
         }
+        else if(!strcmp(argv[i],"-pause-shortcut")){
+            if(i+1<argc){
+                free(arg_return->pause_shortcut);
+                arg_return->pause_shortcut=malloc(strlen(argv[i+1])+1);
+                strcpy(arg_return->pause_shortcut,argv[i+1]);
+            }
+            else{
+                fprintf(stderr,"Argument Usage: -pause-shortcut MOD+KEY\n");
+                return 1;
+            }
+            i++;
+        }
+        else if(!strcmp(argv[i],"-stop-shortcut")){
+            if(i+1<argc){
+                free(arg_return->stop_shortcut);
+                arg_return->stop_shortcut=malloc(strlen(argv[i+1])+1);
+                strcpy(arg_return->stop_shortcut,argv[i+1]);
+            }
+            else{
+                fprintf(stderr,"Argument Usage: -stop-shortcut MOD+KEY\n");
+                return 1;
+            }
+            i++;
+        }
         else if(!strcmp(argv[i],"-buffer-size")){
             if(i+1<argc){
                 int num=atoi(argv[i+1]);
@@ -487,6 +517,17 @@ int ParseArgs(int argc,char **argv,ProgArgs *arg_return){
             }
             i++;
         }
+        else if(!strcmp(argv[i],"-rescue")){
+            if(i+1<argc){
+                int ex_st=rmdRescue(argv[i+1]);
+                exit(ex_st);
+            }
+            else{
+                fprintf(stderr,"Argument Usage: -rescue path_to_data\n");
+                return 1;
+            }
+            i++;
+        }
         else if(!strcmp(argv[i],"--no-sound"))
             arg_return->nosound=1;
         else if(!strcmp(argv[i],"--no-shared")){
@@ -495,6 +536,9 @@ int ParseArgs(int argc,char **argv,ProgArgs *arg_return){
         else if(!strcmp(argv[i],"--full-shots")){
             arg_return->full_shots=1;
         }
+        else if(!strcmp(argv[i],"--no-frame")){
+            arg_return->noframe=1;
+        }
         else if(!strcmp(argv[i],"--follow-mouse")){
             arg_return->full_shots=1;
             arg_return->follow_mouse=1;
