@@ -2,7 +2,7 @@
 *                            recordMyDesktop                                  *
 *******************************************************************************
 *                                                                             *
-*            Copyright (C) 2006,2007 John Varouhakis                          *
+*            Copyright (C) 2006,2007,2008 John Varouhakis                     *
 *                                                                             *
 *                                                                             *
 *   This program is free software; you can redistribute it and/or modify      *
@@ -93,6 +93,11 @@ int PurgeCache(CacheData *cache_data_t,int sound){
             exit_value=1;
         }
     }
+    if(remove(cache_data_t->specsfile)){
+            fprintf(stderr,"Couldn't remove temporary file %s",
+                           cache_data_t->specsfile);
+            exit_value=1;
+    }
     if(remove(cache_data_t->projname)){
         fprintf(stderr,"Couldn't remove temporary directory %s",
                        cache_data_t->projname);
@@ -154,6 +159,10 @@ void InitCacheData(ProgData *pdata,
     cache_data_t->audiodata=malloc(strlen(cache_data_t->projname)+10);
     strcpy(cache_data_t->audiodata,cache_data_t->projname);
     strcat(cache_data_t->audiodata,"audio.pcm");
+    //specsfile
+    cache_data_t->specsfile=malloc(strlen(cache_data_t->projname)+10);
+    strcpy(cache_data_t->specsfile,cache_data_t->projname);
+    strcat(cache_data_t->specsfile,"specs.txt");
 
     //now that've got out buffers and our filenames we start
     //creating the needed files
@@ -187,6 +196,11 @@ void InitCacheData(ProgData *pdata,
            exit(13);
         }
     }
+    if(WriteSpecsFile(pdata)){
+        fprintf(stderr,"Could not write specsfile %s !!!\n",
+                        cache_data_t->specsfile);
+        exit(13);
+    }
 
 }
 
