@@ -2,7 +2,7 @@
 *                            recordMyDesktop                                  *
 *******************************************************************************
 *                                                                             *
-*            Copyright (C) 2006,2007 John Varouhakis                          *
+*            Copyright (C) 2006,2007,2008 John Varouhakis                     *
 *                                                                             *
 *                                                                             *
 *   This program is free software; you can redistribute it and/or modify      *
@@ -39,15 +39,15 @@
 
 
 void rmdThreads(ProgData *pdata){
-    pthread_t   poll_damage_t,
+    pthread_t   poll_events_t,
                 image_capture_t,
                 image_encode_t,
                 image_cache_t,
                 sound_capture_t,
                 sound_encode_t,
                 sound_cache_t,
-                flush_to_ogg_t;
-
+                flush_to_ogg_t,
+                timer_t;
 
     if(pdata->args.delay>0){
         fprintf(stderr,"Will sleep for %d seconds now.\n",pdata->args.delay);
@@ -55,11 +55,6 @@ void rmdThreads(ProgData *pdata){
     }
 
     /*start threads*/
-    if(!pdata->args.full_shots)
-        pthread_create(&poll_damage_t,
-                       NULL,
-                       (void *)PollDamage,
-                       (void *)pdata);
     pthread_create(&image_capture_t,
                    NULL,
                    (void *)GetFrame,
@@ -99,6 +94,11 @@ void rmdThreads(ProgData *pdata){
                        (void *)pdata);
 
     RegisterCallbacks(&pdata->args);
+    pdata->timer_alive=1;
+    pthread_create(&timer_t,
+                   NULL,
+                   (void *)rmdTimer,
+                   (void *)pdata);
     fprintf(stderr,"Capturing!\n");
 #ifdef HAVE_JACK_H
     if(pdata->args.use_jack){
@@ -152,11 +152,9 @@ void rmdThreads(ProgData *pdata){
         pthread_join(flush_to_ogg_t,NULL);
     fprintf(stderr,".");
 
-
-    if(!pdata->args.full_shots)
-        pthread_join(poll_damage_t,NULL);
-
     //Now that we are done with recording we cancel the timer
-    CancelTimer();
+    pdata->timer_alive=0;
+    pthread_join(timer_t,NULL);
+
 
 }
